<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:dk="kelis.fr:dokiel" exclude-result-prefixes="sc sp dk">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no" omit-xml-declaration="yes"/>
	<xsl:param name="vDialog"/>
	<xsl:param name="vAgent"/>
	<xsl:variable name="vId" select="getIdNode(..)"/>
	<xsl:variable name="vImg" select="parseXml(getContent(gotoSubModel(sp:img),'img'))/img"/>
	<xsl:variable name="vDims" select="getContent(gotoSubModel(sp:img),'dims')"/>
	<xsl:variable name="vDimWidth" select="returnFirst(number(substring-before($vDims,',')),0)"/>
	<xsl:variable name="vDimHeight" select="returnFirst(number(substring-after($vDims,',')),0)"/>
	<xsl:variable name="vRatio" select="$vImg/@width div $vDimWidth"/>
	<xsl:variable name="vArea" select="$vDimHeight * $vDimWidth"/>
	<xsl:variable name="vSmallZoneLimit" select="'1000'"/>
	<xsl:template match="*">
		<span style="display:none;">cliquer sur une zone pour connaître son commentaire</span>
		<scBlock class="screenBk">
			<hx class="screenBk_ti">
				<span>
					<xsl:value-of select="getFullTitleText(currentModel(),'')" disable-output-escaping="yes"/>
				</span>
			</hx>
			<div class="screenBk_co">
				<xsl:if test="sp:desc">
					<div class="screenDesc">
						<xsl:value-of select="getContent(gotoSubModel(sp:desc),'')" disable-output-escaping="yes"/>
					</div>
				</xsl:if>
				<div class="screenFra">
					<xsl:variable name="vImgId" select="concat($vId,generate-id(sp:img))"/>
					<div id="{$vImgId}" class="screenImgFra" style="position:relative;height:{$vImg/@height}px;">
						<div class="screenImg" style="position:relative;height:{$vImg/@height}px;width:{$vImg/@width}px;">
							<img src="{$vImg/@src}" width="{$vImg/@width}" height="{$vImg/@height}" class="" alt="getFullTitleText(gotoSubModel(sp:img),'')"/>
							<xsl:apply-templates select="sp:zone" mode="zones"/>
						</div>
					</div>
					<ol class="screenZones">
						<xsl:for-each select="sp:zone">
							<xsl:variable name="vLeft" select="returnFirst(number(substring-before(dk:screenZoneMeta/sp:geo/sp:coords,',')),0)"/>
							<xsl:variable name="vTop" select="returnFirst(number(substring-before(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),',')),0)"/>
							<xsl:variable name="vWidth" select="returnFirst(number(substring-before(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',')) - $vLeft,0)"/>
							<xsl:variable name="vHeight" select="returnFirst(number(substring-after(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',')) - $vTop,0)"/>
							<xsl:variable name="vZoneArea" select="$vWidth * $vHeight"/>
							<li class="screenZone" id="{concat($vId,generate-id(.))}">
								<xsl:if test="dk:screenZoneMeta/sp:title">
									<div class="screenZone_ti">
										<span>
											<xsl:value-of select="dk:screenZoneMeta/sp:title"/>
										</span>
									</div>
								</xsl:if>
								<div class="screenZonePreview">
									<alternative alt="{dk:screenZoneMeta/sp:title}">
										<xsl:choose>
											<xsl:when test="$vZoneArea &lt; $vArea*0.1 or $vHeight &lt; $vDimHeight*0.4 or $vWidth &lt; $vDimWidth*0.4">
												<xsl:value-of select="resultatAgent(concat('@', getIdFromPath(../sp:img/@sc:refUri), '_Acrop/xhtmlContent'),concat(dk:screenZoneMeta/sp:geo/sp:coords,',200,200'))" disable-output-escaping="yes"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="resultatAgent(concat('@', getIdFromPath(../sp:img/@sc:refUri), '_Ahighlight/xhtmlContent'),concat(dk:screenZoneMeta/sp:geo/sp:coords,',200,200'))" disable-output-escaping="yes"/>
											</xsl:otherwise>
										</xsl:choose>
									</alternative>
								</div>
								<div class="screenZone_co">
									<xsl:value-of select="getContent(gotoSubModel(.),'')" disable-output-escaping="yes"/>
								</div>
								<div class="screenZoneEnd">
									<a href="#{$vImgId}">
										<span>Retourner à l&apos;écran</span>
									</a>
								</div>
							</li>
						</xsl:for-each>
					</ol>
				</div>
			</div>
		</scBlock>
	</xsl:template>
	<xsl:template match="sp:zone" mode="zones">
		<xsl:variable name="vLeft" select="returnFirst(number(substring-before(dk:screenZoneMeta/sp:geo/sp:coords,',')),0)"/>
		<xsl:variable name="vTop" select="returnFirst(number(substring-before(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),',')),0)"/>
		<xsl:variable name="vWidth" select="returnFirst(number(substring-before(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',')) - $vLeft,0)"/>
		<xsl:variable name="vHeight" select="returnFirst(number(substring-after(substring-after(substring-after(dk:screenZoneMeta/sp:geo/sp:coords,','),','),',')) - $vTop,0)"/>
		<xsl:variable name="vZneArea" select="$vWidth * $vHeight * $vRatio * $vRatio"/>
		<xsl:variable name="vZneNum" select="count(preceding-sibling::sp:zone)+1"/>
		<a class="screenZoneLnk{si($vZneArea &lt; $vSmallZoneLimit, 'Small', '')}" href="#{concat($vId,generate-id(.))}" style="position:absolute;top:{$vTop * $vRatio}px;left:{$vLeft * $vRatio}px;width:{$vWidth * $vRatio}px;height:{$vHeight * $vRatio}px;">
			<xsl:if test="dk:screenZoneMeta/sp:title">
				<addAttribute name="title" filter="textOnly">
					<xsl:value-of select="$vZneNum"/> - <xsl:value-of select="dk:screenZoneMeta/sp:title"/>
				</addAttribute>
			</xsl:if>
			<span>
				<xsl:value-of select="$vZneNum"/>
			</span>
		</a>
	</xsl:template>
	<xsl:template match="node()" mode="zones"/>
</xsl:stylesheet>