<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:table="urn:oasis:names:tc:opendocument:xmlns:table:1.0"
                xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
                xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0"
                xmlns:draw="urn:oasis:names:tc:opendocument:xmlns:drawing:1.0"
                xmlns:dk="kelis.fr:dokiel" 
                xmlns:style="urn:oasis:names:tc:opendocument:xmlns:style:1.0"
                xmlns:svg="urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0"
                xmlns:sl="http://www.utc.fr/ics/scenari/v3/library" 
                xmlns:fo="urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0"
                xmlns:xlink="http://www.w3.org/1999/xlink" 
                xmlns:java="http://xml.apache.org/xslt/java"
                xmlns:text="urn:oasis:names:tc:opendocument:xmlns:text:1.0"
                xmlns:scodPp="scenari.eu:openDocumentExtension.postprocessing:1.0"
                xmlns:scod="scenari.eu:openDocumentExtension:1.0"
                xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
                xmlns:xalan="http://xml.apache.org/xalan"
                exclude-result-prefixes="table sp office dk style svg sl fo xlink java text scodPp sc xalan">
    <xsl:output omit-xml-declaration="yes" indent="no" method="xml" />
    
    <xsl:param name="vAgent" />
    <xsl:param name="vDialog" />
    <xsl:param name="vArguments"/>
    
    <xsl:variable name="vHighlightColor" select="'black'"/>
    <xsl:variable name="vHighlightLevel" select="'60'"/>
    
    <xsl:template match="/*">
        <!-- 
            argument : 
                - highlight:coord=xx,xx,xx,xx;mW=xx;mH=xx;style=xx;
                - crop:coord=xx,xx,xx,xx;mW=xx;mH=xx;style=xx;
                - zone:coord=xx,xx,xx,xx|xx,xx,xx,xx;mW=xx;mH=xx;style=xx;
         -->
        
        <xsl:choose>
            <xsl:when test="starts-with($vArguments, 'crop:')">
                <xsl:call-template name="tGetCropImg"/>
            </xsl:when>
            <xsl:when test="starts-with($vArguments, 'highlight:')">
                <xsl:call-template name="tGetHighlightImg"/>
            </xsl:when>
             <xsl:when test="starts-with($vArguments, 'zone:')">
                <xsl:call-template name="tGetZoneImg"/>
            </xsl:when>
        </xsl:choose>
        
    </xsl:template>
    
    <!-- ###
           # Image Crop
           ### -->
    <xsl:template name="tGetCropImg" >
        <xsl:variable name="vCropRatio" select="'0.2'"/>
        <xsl:variable name="vCropMarginMin" select="'20'"/>
        
        <xsl:variable name="vDims" select="xalan:tokenize(resultatAgent('//', concat('get:src:', java:hGetUri(srcFileAgent()), '?', 'transform=img2img&amp;sizeRules=&amp;outType=DIMS&amp;outRules=', &quot;Str(pattern'!wpx_!hpx')&quot;)), '_')"/>
        <xsl:variable name="vDimsObj" select="java:com.scenari.s.co.transform.img.ImgUtil.getSize(number($vDims[1]) + 0, number($vDims[2]) + 0, '', '', '', '', '')"/>
        <xsl:variable name="vImgWidth" select="returnFirst(round(java:getWidth($vDimsObj)),0)"/>
        <xsl:variable name="vImgHeight" select="returnFirst(round(java:getHeight($vDimsObj)),0)"/>
        
        <xsl:variable name="vCoord" select="substring-after(substring-before($vArguments,';'), 'coord=')"/>
        <xsl:variable name="vLeft1" select="min(max(returnFirst(number(substring-before($vCoord,',')),0),0),$vImgWidth)"/>
        <xsl:variable name="vTop1" select="min(max(returnFirst(number(substring-before(substring-after($vCoord,','),',')),0),0),$vImgHeight)"/>
        <xsl:variable name="vLeft2" select="min(max(returnFirst(number(substring-before(substring-after(substring-after($vCoord,','),','),',')),$vImgWidth),0),$vImgWidth)"/>
        <xsl:variable name="vTop2" select="min(max(returnFirst(number(substring-after(substring-after(substring-after($vCoord,','),','),',')),$vImgHeight),0),$vImgHeight)"/>
        
        <xsl:variable name="vMaxWidth" select="returnFirst(number(substring-before(substring-after($vArguments, ';mW='), ';')), 15)"/>
        <xsl:variable name="vMaxHeight" select="returnFirst(number(substring-before(substring-after($vArguments, ';mH='), ';')), 20)"/>
        
       
        <xsl:variable name="vHiLeft" select="$vLeft1"/>
        <xsl:variable name="vHiTop" select="$vTop1"/>
        <xsl:variable name="vHiWidth" select="$vLeft2 - $vLeft1"/>
        <xsl:variable name="vHiHeight" select="$vTop2 - $vTop1"/>
        
        <xsl:variable name="vCropMargin" select="max(round(moyenne($vHiWidth*$vCropRatio,$vHiHeight*$vCropRatio)),$vCropMarginMin)"/>
        <xsl:variable name="vCropLeft" select="max($vLeft1 - $vCropMargin,0)"/>
        <xsl:variable name="vCropTop" select="max($vTop1 - $vCropMargin,0)"/>
        <xsl:variable name="vCropWidth" select="min($vLeft2 + $vCropMargin,$vImgWidth) - $vCropLeft"/>
        <xsl:variable name="vCropHeight" select="min($vTop2 + $vCropMargin,$vImgHeight) - $vCropTop"/>
        
        <xsl:variable name="vFinalSizeTransform" select="concat('transform=img2img&amp;sizeRules=Dim(ScSCS(fontPt''12'')Sc(ratio''1''srcDefDpi''96'')Bounds(unit''cm''maxW''',$vMaxWidth,'''maxH''',$vMaxHeight,'''))')"/>
        
        <xsl:variable name="vFinalGenResUri">
            <xsl:value-of select="resultatAgent('//', concat('res:src=src:', java:hGetUri(srcFileAgent()), 
                                                             ';mutabledst=',resultatAgent('/@@/destPathResourcesTmp'), '/',resultatAgent('//outFileName'),
                                                             ';transform=imageMagick&amp;outType=PNG&amp;command=convert%20%24src%20(%20-clone%200%20%2Bcontrast%20%2Bcontrast%20%2Bcontrast%20%2Bcontrast%20-fill%20',$vHighlightColor,'%20-colorize%20',$vHighlightLevel,'%25%20)%20(%20-clone%200%20-crop%20',$vHiWidth,'x',$vHiHeight,'%2B',$vHiLeft,'%2B',$vHiTop,'%20%2Brepage%20)%20-delete%200%20-geometry%20',$vHiWidth,'x',$vHiHeight,'%2B',$vHiLeft,'%2B',$vHiTop,'%20-composite%20%24dst&amp;transform=imageMagick&amp;outType=PNG&amp;command=convert%20%24src%20-crop%20',$vCropWidth,'x',$vCropHeight,'%2B',$vCropLeft,'%2B',$vCropTop,'%20%24dst&amp;', $vFinalSizeTransform, '&amp;outType=PNG'))"/>
        </xsl:variable>
        
        <xsl:variable name="vFinalProps">
            <xsl:value-of select="xalan:tokenize(resultatAgent('//', concat('get:src:', java:hGetUri(srcFileAgent()), '?', 'transform=imageMagick&amp;outType=PNG&amp;command=convert%20%24src%20-crop%20',$vCropWidth,'x',$vCropHeight,'%2B',$vCropLeft,'%2B',$vCropTop,'%20%24dst&amp;', $vFinalSizeTransform, '&amp;outType=DIMS&amp;outRules=', &quot;Str(pattern'w=!wcm;h=!hcm;')&quot;)), '_')"/>
        </xsl:variable>
        <xsl:variable name="vFinalWidth" select="substring-before(substring-after($vFinalProps, 'w='), ';')"/>
        <xsl:variable name="vFinalHeight" select="substring-before(substring-after($vFinalProps, 'h='), ';')"/>
        
        <xsl:call-template name="tGetOd">
            <xsl:with-param name="pFinalWidth"><xsl:value-of select="$vFinalWidth"/></xsl:with-param>
            <xsl:with-param name="pFinalHeight"><xsl:value-of select="$vFinalHeight"/></xsl:with-param>
            <xsl:with-param name="pFinalGenResUri"><xsl:value-of select="$vFinalGenResUri"/></xsl:with-param>
        </xsl:call-template>
    
    </xsl:template>
    
     <!-- ###
           # Image HighlightImg
           ### -->
    <xsl:template name="tGetHighlightImg" >
        <xsl:variable name="vDims" select="xalan:tokenize(resultatAgent('//', concat('get:src:', java:hGetUri(srcFileAgent()), '?', 'transform=img2img&amp;sizeRules=&amp;outType=DIMS&amp;outRules=', &quot;Str(pattern'!wpx_!hpx')&quot;)), '_')"/>
        <xsl:variable name="vDimsObj" select="java:com.scenari.s.co.transform.img.ImgUtil.getSize(number($vDims[1]) + 0, number($vDims[2]) + 0, '', '', '', '', '')"/>
        <xsl:variable name="vImgWidth" select="returnFirst(round(java:getWidth($vDimsObj)),0)"/>
        <xsl:variable name="vImgHeight" select="returnFirst(round(java:getHeight($vDimsObj)),0)"/>
        
        <xsl:variable name="vCoord" select="substring-after(substring-before($vArguments,';'), 'coord=')"/>
        <xsl:variable name="vLeft1" select="min(max(returnFirst(number(substring-before($vCoord,',')),0),0),$vImgWidth)"/>
        <xsl:variable name="vTop1" select="min(max(returnFirst(number(substring-before(substring-after($vCoord,','),',')),0),0),$vImgHeight)"/>
        <xsl:variable name="vLeft2" select="min(max(returnFirst(number(substring-before(substring-after(substring-after($vCoord,','),','),',')),$vImgWidth),0),$vImgWidth)"/>
        <xsl:variable name="vTop2" select="min(max(returnFirst(number(substring-after(substring-after(substring-after($vCoord,','),','),',')),$vImgHeight),0),$vImgHeight)"/>
        
        <xsl:variable name="vMaxWidth" select="returnFirst(number(substring-before(substring-after($vArguments, ';mW='), ';')), 15)"/>
        <xsl:variable name="vMaxHeight" select="returnFirst(number(substring-before(substring-after($vArguments, ';mH='), ';')), 20)"/>
        
        <xsl:variable name="vHiLeft" select="$vLeft1"/>
        <xsl:variable name="vHiTop" select="$vTop1"/>
        <xsl:variable name="vHiWidth" select="$vLeft2 - $vLeft1"/>
        <xsl:variable name="vHiHeight" select="$vTop2 - $vTop1"/>
               
        <xsl:variable name="vFinalSizeTransform" select="concat('transform=img2img&amp;sizeRules=Dim(ScSCS(fontPt''12'')Sc(ratio''1''srcDefDpi''96'')Bounds(unit''cm''maxW''',$vMaxWidth,'''maxH''',$vMaxHeight,'''))')"/>
        
        <xsl:variable name="vFinalGenResUri">
            <xsl:value-of select="resultatAgent('//', concat('res:src=src:', java:hGetUri(srcFileAgent()), 
                                                      ';mutabledst=',resultatAgent('/@@/destPathResourcesTmp'), '/',resultatAgent('//outFileName'),
                                                      ';transform=imageMagick&amp;outType=PNG&amp;command=convert%20%24src%20(%20-clone%200%20%2Bcontrast%20%2Bcontrast%20%2Bcontrast%20%2Bcontrast%20-fill%20',$vHighlightColor,'%20-colorize%20',$vHighlightLevel,'%25%20)%20(%20-clone%200%20-crop%20',$vHiWidth,'x',$vHiHeight,'%2B',$vHiLeft,'%2B',$vHiTop,'%20%2Brepage%20)%20-delete%200%20-geometry%20',$vHiWidth,'x',$vHiHeight,'%2B',$vHiLeft,'%2B',$vHiTop,'%20-composite%20%24dst&amp;', $vFinalSizeTransform, '&amp;outType=PNG'))"/>
        </xsl:variable>
        
        <xsl:variable name="vFinalProps">
            <xsl:value-of select="xalan:tokenize(resultatAgent('//', concat('get:src:', java:hGetUri(srcFileAgent()), '?', $vFinalSizeTransform, '&amp;outType=DIMS&amp;outRules=', &quot;Str(pattern'w=!wcm;h=!hcm;')&quot;)), '_')"/>
        </xsl:variable>
        <xsl:variable name="vFinalWidth" select="substring-before(substring-after($vFinalProps, 'w='), ';')"/>
        <xsl:variable name="vFinalHeight" select="substring-before(substring-after($vFinalProps, 'h='), ';')"/>
        
        <xsl:call-template name="tGetOd">
            <xsl:with-param name="pFinalWidth"><xsl:value-of select="$vFinalWidth"/></xsl:with-param>
            <xsl:with-param name="pFinalHeight"><xsl:value-of select="$vFinalHeight"/></xsl:with-param>
            <xsl:with-param name="pFinalGenResUri"><xsl:value-of select="$vFinalGenResUri"/></xsl:with-param>
        </xsl:call-template>
    
    </xsl:template>
    
     <!-- ###
           # Image ZoneImg
           ### -->
    <xsl:template name="tGetZoneImg" >
        <xsl:variable name="vDims" select="xalan:tokenize(resultatAgent('//', concat('get:src:', java:hGetUri(srcFileAgent()), '?', 'transform=img2img&amp;sizeRules=&amp;outType=DIMS&amp;outRules=', &quot;Str(pattern'!wpx_!hpx')&quot;)), '_')"/>
        <xsl:variable name="vDimsObj" select="java:com.scenari.s.co.transform.img.ImgUtil.getSize(number($vDims[1]) + 0, number($vDims[2]) + 0, '', '', '', '', '')"/>
        <xsl:variable name="vImgWidth" select="returnFirst(round(java:getWidth($vDimsObj)),0)"/>
        <xsl:variable name="vImgHeight" select="returnFirst(round(java:getHeight($vDimsObj)),0)"/>
    
        <xsl:variable name="vMaxWidth" select="returnFirst(number(substring-before(substring-after($vArguments, ';mW='), ';')), 15)"/>
        <xsl:variable name="vMaxHeight" select="returnFirst(number(substring-before(substring-after($vArguments, ';mH='), ';')), 20)"/>
        <xsl:variable name="vFinalSizeTransform" select="concat('transform=img2img&amp;sizeRules=Dim(ScSCS(fontPt''12'')Sc(ratio''1''srcDefDpi''96'')Bounds(unit''cm''maxW''',$vMaxWidth,'''maxH''',$vMaxHeight,'''))')"/>
        
        <xsl:variable name="vIniProps">
            <xsl:value-of select="xalan:tokenize(resultatAgent('//', concat('get:src:', java:hGetUri(srcFileAgent()), '?transform=img2img&amp;sizeRules=Dim(Sc(ratio''1''srcDefDpi''96''))&amp;outType=DIMS&amp;outRules=', &quot;Str(pattern'w=!wcm;h=!hcm;')&quot;)), '_')"/>
        </xsl:variable>
        <xsl:variable name="vFinalProps">
            <xsl:value-of select="xalan:tokenize(resultatAgent('//', concat('get:src:', java:hGetUri(srcFileAgent()), '?', $vFinalSizeTransform, '&amp;outType=DIMS&amp;outRules=', &quot;Str(pattern'w=!wcm;h=!hcm;')&quot;)), '_')"/>
        </xsl:variable>
        <xsl:variable name="vFinalWidth" select="substring-before(substring-after($vFinalProps, 'w='), ';')"/>
        <xsl:variable name="vFinalHeight" select="substring-before(substring-after($vFinalProps, 'h='), ';')"/>
        <xsl:variable name="vFactor" select="$vFinalHeight div substring-before(substring-after($vIniProps, 'h='), ';')"/><!-- facteur de réduction -->
        
        <xsl:variable name="vFontSize" select="12 div $vFactor"/>
        <xsl:variable name="vMargin" select="2 div $vFactor"/>
        
        <xsl:variable name="vCoord" select="substring-after(substring-before($vArguments,';'), 'coord=')"/>
        
        <xsl:variable name="vImgMagicAppendZoneTransform">
            <xsl:text>command=convert%20%24src%20</xsl:text>
            <xsl:for-each select="xalan:tokenize($vCoord, '|')">
                <xsl:variable name="vLeft1" select="min(max(returnFirst(number(substring-before(.,',')),0),0),$vImgWidth)"/>
                <xsl:variable name="vTop1" select="min(max(returnFirst(number(substring-before(substring-after(.,','),',')),0),0),$vImgHeight)"/>
                <xsl:variable name="vLeft2" select="min(max(returnFirst(number(substring-before(substring-after(substring-after(.,','),','),',')),$vImgWidth),0),$vImgWidth)"/>
                <xsl:variable name="vTop2" select="min(max(returnFirst(number(substring-after(substring-after(substring-after(.,','),','),',')),$vImgHeight),0),$vImgHeight)"/>
                
                <xsl:variable name="vHiLeft" select="$vLeft1"/>
                <xsl:variable name="vHiTop" select="$vTop1"/>
                <xsl:variable name="vHiWidth" select="$vLeft2 - $vLeft1"/><!-- Taille minimale -->
                <xsl:variable name="vHiHeight" select="$vTop2 - $vTop1"/><!-- Taille minimale -->
                
                <xsl:text>(%20-clone%200%20-crop%20</xsl:text><xsl:value-of select="$vHiWidth"/>x<xsl:value-of select="$vHiHeight"/>%2B<xsl:value-of select="$vHiLeft"/>%2B<xsl:value-of select="$vHiTop"/>%20%2Brepage%20%2Bcontrast%20%2Bcontrast%20%2Bcontrast%20%2Bcontrast%20-fill%20%22#FFC726%22%20-colorize%2060%25%20-geometry%20<xsl:value-of select="$vHiWidth"/>x<xsl:value-of select="$vHiHeight"/>%2B<xsl:value-of select="$vHiLeft"/>%2B<xsl:value-of select="$vHiTop"/><xsl:text>%20)%20-composite%20</xsl:text>
                <xsl:text>-pointsize%20</xsl:text><xsl:value-of select="$vFontSize"/>%20-family%20arial%20-fill%20%22#000000%22%20-weight%20bold%20-draw%20%22text%20<xsl:value-of select="$vHiLeft + $vMargin"/>,<xsl:value-of select="$vHiTop + $vFontSize"/>%20'<xsl:value-of select="position()"/>*<xsl:text>'%22%20</xsl:text>
            </xsl:for-each>
            <xsl:text>%24dst</xsl:text>
        </xsl:variable>
        
        <xsl:variable name="vFinalGenResUri">
            <xsl:value-of select="resultatAgent('//', concat('res:src=src:', java:hGetUri(srcFileAgent()), 
                                                      ';mutabledst=',resultatAgent('/@@/destPathResourcesTmp'), '/',resultatAgent('//outFileName'),
                                                      ';transform=imageMagick&amp;outType=PNG&amp;',$vImgMagicAppendZoneTransform,'&amp;', $vFinalSizeTransform, '&amp;outType=PNG'))"/>
        </xsl:variable>
        
        <xsl:call-template name="tGetOd">
            <xsl:with-param name="pFinalWidth"><xsl:value-of select="$vFinalWidth"/></xsl:with-param>
            <xsl:with-param name="pFinalHeight"><xsl:value-of select="$vFinalHeight"/></xsl:with-param>
            <xsl:with-param name="pFinalGenResUri"><xsl:value-of select="$vFinalGenResUri"/></xsl:with-param>
        </xsl:call-template>
    
    </xsl:template>
    
    
    <xsl:template name="tGetOd">
        <xsl:param name="pFinalHeight"/>
        <xsl:param name="pFinalWidth"/>
        <xsl:param name="pFinalGenResUri"/>
        
        <xsl:variable name="vStyle" select="concat('_globalsStyles_', returnFirst(substring-before(substring-after($vArguments, 'style='), ';'), 'resDefault'))"/>
        
        <xsl:variable name="vExistRes" select="java:getContentStatus(java:findNodeChild(srcFileAgent(), java:getSrcName(srcFileAgent())))='1'"/>
        <xsl:comment>
            ### scr Transform ###
        </xsl:comment>
        
        <xsl:choose>
            <xsl:when test="$vExistRes">
                <draw:frame   svg:height="{normalize-space($pFinalHeight)}cm" 
                              svg:width="{normalize-space($pFinalWidth)}cm"
                              svg:y="{getEntryBuffer('odStyleBlocks', $vStyle)/text:p/draw:frame/@svg:y}"
                              svg:x="{getEntryBuffer('odStyleBlocks', $vStyle)/text:p/draw:frame/@svg:x}"
                              draw:z-index="{getEntryBuffer('odStyleBlocks', $vStyle)/text:p/draw:frame/@draw:z-index}"
                              text:anchor-type="{getEntryBuffer('odStyleBlocks', $vStyle)/text:p/draw:frame/@text:anchor-type}"
                              draw:style-name="{getEntryBuffer('odStyleBlocks', $vStyle)/text:p/draw:frame/@draw:style-name}"
                              draw:name="{local-name()}">
                    <draw:image>
                        <xsl:attribute name="scod:src"><xsl:value-of select="concat('dest:', $pFinalGenResUri)" /></xsl:attribute>
                        <xsl:attribute name="xlink:type">simple</xsl:attribute>
                        <xsl:attribute name="xlink:show">embed</xsl:attribute>
                        <xsl:attribute name="xlink:actuate">onLoad</xsl:attribute>
                    </draw:image>
                </draw:frame>
            </xsl:when>
            <xsl:otherwise>
                <scodPp:error text="Image manquante" phase="generation" type="error">
                    La ressource '<xsl:value-of select="resultatAgent('//outFileName')" />' est introuvable.
                </scodPp:error>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="*" />
    
</xsl:stylesheet>